@@ -31,4 +31,16 @@ describe('Filter: orderBy', function() {
     toEqual([{a:2, b:1},{a:15, b:1}]);
   });
 
+  it('should support string predicates with names containing non-identifier characters', function() {
+    expect(orderBy([{"Tip %": .25}, {"Tip %": .15}, {"Tip %": .40}], '"Tip %"'))
+      .toEqualData([{"Tip %": .15}, {"Tip %": .25}, {"Tip %": .40}]);
+    expect(orderBy([{"원": 76000}, {"원": 31000}, {"원": 156000}], '"원"'))
+      .toEqualData([{"원": 31000}, {"원": 76000}, {"원": 156000}])
+  });
+
+  it('should throw if quoted string predicate is quoted incorrectly', function() {
+    expect(function() {
+      return orderBy([{"Tip %": .15}, {"Tip %": .25}, {"Tip %": .40}], '"Tip %\'');
+    }).toThrow();
+  });
 });
